==> ejc-zjkjcost-api-3.0.0-20220622.074609-6-sources.jar: com/ejianc/business/zjkjcost/finish/vo/OutDetailVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-竣工目标考核奖金发放-子表
 * 
 * @author generator
 * 
 */
@ApiModel("竣工考核-竣工目标考核奖金发放-子表")
public class OutDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表id")
    private Long outId;
    @ApiModelProperty("姓名")
    private String userName;
    @ApiModelProperty("岗位")
    private String job;
    @ApiModelProperty("分配人签字")
    private String sign;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("实发金额")
    private BigDecimal detailActualMny;
    

    /**
     * 主表id
     */
    public Long getOutId() {
        return outId;
    }

    /**
     * 主表id
     */
    public void setOutId(Long outId) {
        this.outId = outId;
    }
    /**
     * 姓名
     */
    public String getUserName() {
        return userName;
    }

    /**
     * 姓名
     */
    public void setUserName(String userName) {
        this.userName = userName;
    }
    /**
     * 岗位
     */
    public String getJob() {
        return job;
    }

    /**
     * 岗位
     */
    public void setJob(String job) {
        this.job = job;
    }
    /**
     * 分配人签字
     */
    public String getSign() {
        return sign;
    }

    /**
     * 分配人签字
     */
    public void setSign(String sign) {
        this.sign = sign;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 实发金额
     */
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    /**
     * 实发金额
     */
    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    
}

==> ejc-zjkjcost-api-3.0.0-20220629.013418-19-sources.jar: com/ejianc/business/zjkjcost/finish/vo/OutDetailVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-竣工目标考核奖金发放-子表
 * 
 * @author generator
 * 
 */
@ApiModel("竣工考核-竣工目标考核奖金发放-子表")
public class OutDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表id")
    private Long outId;
    @ApiModelProperty("姓名")
    private String userName;
    @ApiModelProperty("岗位")
    private String job;
    @ApiModelProperty("分配人签字")
    private String sign;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("实发金额")
    private BigDecimal detailActualMny;
    @TableField(value="detail_out_mny")
    private BigDecimal detailOutMny; // 分配金额

    public BigDecimal getDetailOutMny() {
        return detailOutMny;
    }

    public void setDetailOutMny(BigDecimal detailOutMny) {
        this.detailOutMny = detailOutMny;
    }


    /**
     * 主表id
     */
    public Long getOutId() {
        return outId;
    }

    /**
     * 主表id
     */
    public void setOutId(Long outId) {
        this.outId = outId;
    }
    /**
     * 姓名
     */
    public String getUserName() {
        return userName;
    }

    /**
     * 姓名
     */
    public void setUserName(String userName) {
        this.userName = userName;
    }
    /**
     * 岗位
     */
    public String getJob() {
        return job;
    }

    /**
     * 岗位
     */
    public void setJob(String job) {
        this.job = job;
    }
    /**
     * 分配人签字
     */
    public String getSign() {
        return sign;
    }

    /**
     * 分配人签字
     */
    public void setSign(String sign) {
        this.sign = sign;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 实发金额
     */
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    /**
     * 实发金额
     */
    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    
}
